@@ -38,7 +38,7 @@ class Response(object):
 
 class PluginManager(InstanceManager):
     def all(self):
-        for plugin in super(PluginManager, self).all():
+        for plugin in sorted(super(PluginManager, self).all(), key=lambda x: x.get_title()):
             if not plugin.is_enabled():
                 continue
             yield plugin
@@ -413,6 +413,17 @@ class IPlugin(local):
         >>>     print 'New event created:', event.id
         """
 
+    def get_filters(self, project=None, **kwargs):
+        """
+        Provides additional filters to the builtins.
+
+        Must return an iterable.
+
+        >>> def get_filters(self, project, **kwargs):
+        >>>     return [MyFilterClass]
+        """
+        return []
+
 
 class Plugin(IPlugin):
     """
